@@ -25,4 +25,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 from keithley2600.result_table import ResultTable, FETResultTable
 from keithley2600.keithley_driver import Keithley2600Factory as Keithley2600
-from keithley2600.keithley_driver import log_to_screen
+from keithley2600.keithley_driver import log_to_screen, KeithleyIOError
+
+
+__version__ = "v2.0.0"
